==> kubernetes-model-core-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/FCVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class FCVolumeSourceBuilder extends FCVolumeSourceFluentImpl<FCVolumeSourceBuilder> implements VisitableBuilder<FCVolumeSource,FCVolumeSourceBuilder> {

    FCVolumeSourceFluent<?> fluent;
    Boolean validationEnabled;

    public FCVolumeSourceBuilder() {
        this(true);
    }

    public FCVolumeSourceBuilder(Boolean validationEnabled) {
        this(new FCVolumeSource(), validationEnabled);
    }

    public FCVolumeSourceBuilder(FCVolumeSourceFluent<?> fluent) {
        this(fluent, true);
    }

    public FCVolumeSourceBuilder(FCVolumeSourceFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new FCVolumeSource(), validationEnabled);
    }

    public FCVolumeSourceBuilder(FCVolumeSourceFluent<?> fluent,FCVolumeSource instance) {
        this(fluent, instance, true);
    }

    public FCVolumeSourceBuilder(FCVolumeSourceFluent<?> fluent,FCVolumeSource instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withFsType(instance.getFsType()); 
        fluent.withLun(instance.getLun()); 
        fluent.withReadOnly(instance.getReadOnly()); 
        fluent.withTargetWWNs(instance.getTargetWWNs()); 
        fluent.withWwids(instance.getWwids()); 
        this.validationEnabled = validationEnabled; 
    }

    public FCVolumeSourceBuilder(FCVolumeSource instance) {
        this(instance,true);
    }

    public FCVolumeSourceBuilder(FCVolumeSource instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withFsType(instance.getFsType()); 
        this.withLun(instance.getLun()); 
        this.withReadOnly(instance.getReadOnly()); 
        this.withTargetWWNs(instance.getTargetWWNs()); 
        this.withWwids(instance.getWwids()); 
        this.validationEnabled = validationEnabled; 
    }

    public FCVolumeSource build() {
        FCVolumeSource buildable = new FCVolumeSource(fluent.getFsType(),fluent.getLun(),fluent.getReadOnly(),fluent.getTargetWWNs(),fluent.getWwids());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        FCVolumeSourceBuilder that = (FCVolumeSourceBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-core-5.3.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/FCVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class FCVolumeSourceBuilder extends FCVolumeSourceFluentImpl<FCVolumeSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<FCVolumeSource,FCVolumeSourceBuilder> {

    FCVolumeSourceFluent<?> fluent;
    Boolean validationEnabled;

    public FCVolumeSourceBuilder() {
        this(true);
    }

    public FCVolumeSourceBuilder(Boolean validationEnabled) {
        this(new FCVolumeSource(), validationEnabled);
    }

    public FCVolumeSourceBuilder(FCVolumeSourceFluent<?> fluent) {
        this(fluent, true);
    }

    public FCVolumeSourceBuilder(FCVolumeSourceFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new FCVolumeSource(), validationEnabled);
    }

    public FCVolumeSourceBuilder(FCVolumeSourceFluent<?> fluent,FCVolumeSource instance) {
        this(fluent, instance, true);
    }

    public FCVolumeSourceBuilder(FCVolumeSourceFluent<?> fluent,FCVolumeSource instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withFsType(instance.getFsType()); 
        fluent.withLun(instance.getLun()); 
        fluent.withReadOnly(instance.getReadOnly()); 
        fluent.withTargetWWNs(instance.getTargetWWNs()); 
        fluent.withWwids(instance.getWwids()); 
        this.validationEnabled = validationEnabled; 
    }

    public FCVolumeSourceBuilder(FCVolumeSource instance) {
        this(instance,true);
    }

    public FCVolumeSourceBuilder(FCVolumeSource instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withFsType(instance.getFsType()); 
        this.withLun(instance.getLun()); 
        this.withReadOnly(instance.getReadOnly()); 
        this.withTargetWWNs(instance.getTargetWWNs()); 
        this.withWwids(instance.getWwids()); 
        this.validationEnabled = validationEnabled; 
    }

    public FCVolumeSource build() {
        FCVolumeSource buildable = new FCVolumeSource(fluent.getFsType(),fluent.getLun(),fluent.getReadOnly(),fluent.getTargetWWNs(),fluent.getWwids());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        FCVolumeSourceBuilder that = (FCVolumeSourceBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
